@@ -59,12 +59,13 @@ struct FileInfoParam : TextDocumentParam {
   bool includes = false;
   bool skipped_ranges = false;
 };
-REFLECT_STRUCT(FileInfoParam, textDocument, dependencies, includes, skipped_ranges);
+REFLECT_STRUCT(FileInfoParam, textDocument, dependencies, includes,
+               skipped_ranges);
 
 void MessageHandler::ccls_fileInfo(JsonReader &reader, ReplyOnce &reply) {
   FileInfoParam param;
-  Reflect(reader, param);
-  QueryFile *file = FindFile(param.textDocument.uri.GetPath());
+  reflect(reader, param);
+  QueryFile *file = findFile(param.textDocument.uri.getPath());
   if (!file)
     return;
 
